SchemaError constructor

SchemaError(
  1. Iterable<StandardIssue> issues
)

Wraps issues.

Throws ArgumentError when issues is empty because message is taken from the first issue, matching the upstream utility.

Implementation

SchemaError(Iterable<StandardIssue> issues) : this._(_snapshotIssues(issues));