SchemaError class
An Exception wrapping the issues of a failed Standard Schema validation, exposing the first issue's message. The standard way to throw on failure.
Dart port of SchemaError from @standard-schema/utils.
- Implemented types
Constructors
-
SchemaError(Iterable<
StandardIssue> issues) -
Wraps
issues.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
issues
→ List<
StandardIssue> -
The issues describing why validation failed. Never empty.
final
- message → String
-
The error message, taken from the first issue.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited